@@ -1,4 +1,4 @@
--- This file is part of Quipper. Copyright (C) 2011-2013. Please see the
+-- This file is part of Quipper. Copyright (C) 2011-2014. Please see the
 -- file COPYRIGHT for a list of authors, copyright holders, licensing,
 -- and other details. All rights reserved.
 -- 
@@ -41,7 +41,7 @@ import Libraries.Auxiliary
 -- we use the state monad to hold our \"quantum\" state
 import Control.Monad.State
 -- we use complex numbers as our probability amplitudes
-import Libraries.Synthesis.Ring (Cplx (..), i)
+import Quantum.Synthesis.Ring (Cplx (..), i)
 -- we use a random number generator to simulate \"quantum randomness\"
 import System.Random hiding (split)
 -- we store \"basis\" states as a map, 
